const axios     = require('axios');
const fs        = require('fs');
const settings  = require('../settings.js');
const FormData  = require('form-data');
const utils     = require('./utils');


// LOGIN
// ---------------------------------------------------------------------------------
exports.login = function login(callback) {

    return new Promise(function(resolve, reject) {
    
        let params = new URLSearchParams();
            params.append('client_id'    , settings.clientId);
            params.append('client_secret', settings.clientSecret);
            params.append('grant_type'   , 'client_credentials'); 
            params.append('scope'        , 'data:read');
        
        axios.post('https://developer.api.autodesk.com/authentication/v1/authenticate', params.toString()).then(function (response) {

            if (response.status == 200) {               

                axios.defaults.headers.common['Content-Type']   = 'application/json';
                axios.defaults.headers.common['Accept']         = 'application/json';
                axios.defaults.headers.common['X-user-id']      = settings.user;
                axios.defaults.headers.common['X-Tenant']       = settings.tenant;
                axios.defaults.headers.common['Authorization']  = 'Bearer ' + response.data.access_token;
                
                console.log('    Login to F3M tenant ' + settings.tenant + ' successful');

                return resolve();

            } else {

                console.log();      
                console.log('!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!');      
                console.log('             LOGIN FAILED');
                console.log('!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!'); 
                console.log(); 
                
                console.log(error);

                return reject();

            }

        }).catch(function (error) {
            console.log(error);
        });

    });
    
}


// SCHEMA
// ---------------------------------------------------------------------------------
exports.getFieldSectionId = function getFieldSectionId(wsId, fieldId) {
    
    // Get ID of section that contains defined field

    console.log('    Getting Section ID'); 
    
    let url = 'https://' + settings.tenant + '.autodeskplm360.net/api/rest/v1/workspaces/' + wsId + '/sections';
    
    return axios.get(url).then(function (response) {
        
        let sectionId = -1;

        if(response.data.list === null) {

            console.log();
            console.log('    ERROR in getting sections of workspace ' + wsId);
            console.log();

        } else {
        
            for(section of response.data.list.section) {
                
                if(section.hasOwnProperty('field')) {
                    for(field of section.field) {
                    
                        let temp = field.split('/');
                        let id   = temp[temp.length - 1];
                        
                        if(id === fieldId) {
                            sectionId = section.sectionID;
                            break;
                        }
                        
                    }
                }
                
            }
            
            if(sectionId === -1) {
                console.log('    ERROR: Could not find field ' + fieldId + ' in workspace ' + workspaceId);
            } else {
                console.log('    Sectiond ID is ' + sectionId);
            }  

        }

        return sectionId;

    }).catch(function (error) {
        console.log(error.message);
    });
     
}
exports.getWorkspaces = function getWorkspaces() {

    let url = 'https://' + settings.tenant + '.autodeskplm360.net/api/v3/workspaces?offset=0&limit=500';
    
    return axios.get(url).then(function (response) {
        return response.data;
    }).catch(function (error) {
        console.log(error.message);
        return [];
    });

}
exports.getWorkspaceTabs = function getWorkspaceTabs(wsId) {

    let url = 'https://' + settings.tenant + '.autodeskplm360.net/api/v3/workspaces/' + wsId + '/tabs';
    
    return axios.get(url).then(function (response) {
        return response.data;
    }).catch(function (error) {
        console.log(error.message);
        return [];
    });

}


// QUERY DATA
// ---------------------------------------------------------------------------------
exports.search = function search(params) {

    let url = 'https://' + settings.tenant + '.autodeskplm360.net/api/rest/v1/workspaces/' + params.wsId + '/items/search';
    
    return axios.post(url, {
        'pageNo'      : (typeof params.pageNo === 'undefined') ? 1 : params.pageNo,
        'pageSize'    : (typeof params.pageSize === 'undefined') ? 100 : params.pageSize,
        'logicClause' : (typeof params.logicClause === 'undefined') ? 'AND' : params.logicClause,
        'fields'      : params.fields,
        'filter' : params.filter,
        'sort' : [{
            'fieldID'        : 'TITLE',
            'fieldTypeID'    : 0,
            'sortDescending' : false
        }]
    }).then(function (response) {
        let result = response.data;
        if(result === '') {
            result = {
                'totalResultCount' : 0,
                'row' : []
            }
        }
        return result;
    }).catch(function (error) {
        console.log(error);    
        return [];
    });

}
exports.query = function query(params) {

    let limit    = (typeof params.limit    === 'undefined') ?   100 : params.limit;
    let offset   = (typeof params.offset   === 'undefined') ?     0 : params.offset;
    let revision = (typeof params.revision === 'undefined') ?   '2' : params.revision;
    let bulk     = (typeof params.bulk     === 'undefined') ? false : params.bulk;

    let url = 'https://' + settings.tenant + '.autodeskplm360.net/api/v3/search-results?limit=' + limit + '&offset=' + offset + '&query=' + params.query;
    
    if(typeof params.wsId !== 'undefined') url += '+AND+(workspaceId%3D' + params.wsId + ')';
    url += '&revision=' + revision;

    if(bulk) {
        return axios.get(url,{
            headers : {
                'Accept' : 'application/vnd.autodesk.plm.items.bulk+json'
            }
        }).then(function(response) {
            return response.data;
        }).catch(function(error) {
            console.log(error);
            return [];
        });
    } else {
        return axios.get(url).then(function(response) {
            return response.data;
        }).catch(function(error) {
            console.log(error);
            return [];
        });
    }

}
exports.requestReport = function requestReport(reportId) {

    let url = 'https://' + settings.tenant + '.autodeskplm360.net/api/rest/v1/reports/' + reportId;
    
    return axios.get(url).then(function (response) {
        return response.data;
    }).catch(function (error) {
        utils.printError(error.message);
        return false;
    });

}


// RECORDS MANAGEMENT
// ---------------------------------------------------------------------------------
exports.createItem = function createItem(params) {

    return new Promise(function(resolve, reject) {

        let prefix   = '/api/v3/workspaces/' + params.wsId;
        let url      = 'https://' + settings.tenant + '.autodeskplm360.net' + prefix + '/items';
        let sections = [];
                
        for(section of params.sections) {
    
            let sect = {
                'link'   : prefix + '/sections/' + section.id,
                'fields' : []
            }
    
            for(field of section.fields) {
                sect.fields.push({
                    '__self__'  : prefix + '/views/1/fields/' + field.fieldId,
                    'value'     : field.value
                });
            }
    
            sections.push(sect);
    
        }

        axios.post(url, {
            'sections' : sections
        }, { 'headers' : headers }).then(function (response) {           
            return resolve(response.headers.location);
        }).catch(function (error) {
            console.log(error.message);
            return reject(error.message);
        });
        
    });

}
exports.archiveItem = function archiveItem(link) {

    let url = 'https://' + settings.tenant + '.autodeskplm360.net' + link + '?deleted=true';

    return axios.patch(url, {}, {
        headers : {
            'Content-Type' : 'application/json'
        }
    }).then(function () {
        return true;
    }).catch(function (error) {
        console.log(error);
        return false;
    });
        

}


// ITEM DETAILS
// ---------------------------------------------------------------------------------
exports.getDetails = function getDetails(wsId, dmsId) {

    let url = 'https://' + settings.tenant + '.autodeskplm360.net/api/v3/workspaces/' + wsId + '/items/' + dmsId;
    
    return axios.get(url).then(function (response) {
        return response.data;
    }).catch(function (error) {
        console.log(error.message);
        return [];
    });

}
exports.edit = function edit(params) {

    let prefix   = (typeof params.link !== 'undefined') ? params.link : '/api/v3/workspaces/' + params.wsId + '/items/' + params.dmsId;
    let url      = 'https://' + settings.tenant + '.autodeskplm360.net' + prefix;
    let sections = [];

    for(section of params.sections) {

        let sect = {
            'link'   : prefix + '/views/1/sections/' + section.id,
            'fields' : []
        }

        for(field of section.fields) {

            sect.fields.push({
                '__self__'  : prefix + '/views/1/fields/' + field.fieldId,
                'urn'       : 'urn:adsk.plm:tenant.workspace.item.view.field:' + settings.tenant.toUpperCase() + '.' + params.wsId + '.' + params.dmsId + '.1.' + field.fieldId,
                'value'     : field.value
            });

        }

        sections.push(sect);

    }

    return axios.patch(url, {
        'sections' : sections
    }).then(function () {
        return true;
    }).catch(function (error) {
        console.log(error.message);
        return false;
    });

}
exports.uploadImage = function uploadImage(params) {

    return new Promise(function(resolve, reject) {

        let url = 'https://' + settings.tenant + '.autodeskplm360.net/api/v3/workspaces/' + params.wsId + '/items/' + params.dmsId;
        let formData = new FormData();

        formData.append(params.fieldId, fs.createReadStream(params.folder + '/' + params.fileName), {
            contentType: 'application/octet-stream'
        });      
    
        axios.get(url, { 'headers' : headers }).then(function (response) {
           
            formData.append('itemDetail', JSON.stringify(response.data), {
                filename    : 'blob',
                contentType : 'application/json'
            });

            let custHeaders                   = formData.getHeaders();
                custHeaders['X-user-id']      = settings.f3mUser;
                custHeaders['X-Tenant']       = settings.tenant;
                custHeaders['Authorization']  = headers['Authorization'];

            axios.put(url, formData, {
                'headers' : custHeaders
            }).then(function (response) {
                // if(response.status === 204) {
                //     console.log('    Image upload successful');
                // } else {
                //    console.log('    Status code : ' + response.status); 
                // }
                return resolve();
            }).catch(function (error) {
                console.log(error);
                return reject();
            });
                        
        }).catch(function (error) {
            console.log(error);    
        });

    });

}


// ITEM BOM
// ---------------------------------------------------------------------------------
exports.getBOMViews = function getBOMViews(wsId) {

    let url = 'https://' + settings.tenant + '.autodeskplm360.net/api/v3/workspaces/' + wsId + '/views/5';
    
    return axios.get(url).then(function (response) {
        return response.data;
    }).catch(function (error) {
        console.log(error.message);
        return [];
    });

}
exports.getFlatBOM = function getBOMViews(params) {

    let url = 'https://' + settings.tenant + '.autodeskplm360.net/api/v3/workspaces/' + params.wsId + '/items/' + params.dmsId + '/bom-items?effectiveDate=2020-06-25&revisionBias=release&rootId=' + params.dmsId + '&viewDefId=' + params.viewId;
    
    return axios.get(url, {
        'headers': {
            'Accept': 'application/vnd.autodesk.plm.bom.flat.bulk+json'
        }
    }).then(function (response) {
        return response.data;
    }).catch(function (error) {
        console.log(error.message);
        return [];
    });

}
exports.addBomItem = function addBomItem(params) {

    return new Promise(function(resolve, reject) {
    
        let url = 'https://' + settings.tenant + '.autodeskplm360.net/api/v3/workspaces/' + params.wsIdParent + '/items/' + params.dmsIdParent + '/bom-items';
        let isPinned = (typeof params.pinned === 'undefined') ? false : params.pinned;

        let bomEntry = {
            'quantity'  : params.qty,
            'isPinned'  : isPinned,
            'item'      : { 
                'link'  : '/api/v3/workspaces/' + params.wsIdChild + '/items/' + params.dmsIdChild
            }
        };

        if(typeof params.number !== 'undefined') bomEntry.itemNumber = params.number;

        axios.post(url, bomEntry, {
            'headers' : headers
        }).then(function(response) {
            return resolve(response.data);
        }).catch(function(error) {
            console.log(error);
        });

    });

}


// ITEM ATTACHMENTS
// ---------------------------------------------------------------------------------
exports.getAttachments = function getAttachments(wsId, dmsId) {

    let url = 'https://' + settings.tenant + '.autodeskplm360.net/api/v3/workspaces/' + wsId + '/items/' + dmsId + '/attachments?asc=name';
    
    return axios.get(url, {
        'headers' : {
            'Accept': 'application/vnd.autodesk.plm.attachments.bulk+json'
        }
    }).then(function (response) {
        return response.data;
    }).catch(function (error) {
        console.log(error.message);
        return [];
    });

}
exports.uploadFile = function uploadFile(link, path, fileName, folderName) {
    
    return new Promise(function(resolve, reject) {

        let prefix = 'https://' + settings.tenant + '.autodeskplm360.net/' + link;

        getAttachments(prefix, function(attachments) {
            parseAttachments(prefix, path, fileName, folderName, attachments, function() {
                return resolve();
            });

        });

    });

}
function getAttachments(prefix, callback) {
    
    let url = prefix + '/attachments?asc=name';
    
    axios.get(url, {
        'headers' : {
            'Accept': 'application/vnd.autodesk.plm.attachments.bulk+json'
        }
    }).then(function (response) {
        callback(response);
    }).catch(function (error) {
        console.log(' > getAttachments ERROR');
        console.log(error.message);
    });  
    
}
function parseAttachments(prefix, path, fileName, folderName, attachments, callback) {

    let folderId    = '';
    let fileId      = '';

    if(attachments.status === 200) {
        for(attachment of attachments.data.attachments) {
            if(attachment.name === fileName) {
                fileId = attachment.id;
            } 
            if(attachment.folder !== null) {
                if(attachment.folder.name === folderName) {
                    folderId = { id : attachment.folder.id };
                }
            }
        }
    }

    if(fileId !== '') {
        createVersion(prefix, path, fileName, folderId, fileId, function() { callback(); });
    } else if(folderName === '') {
        createFile(prefix, path, fileName, null, function() { callback(); });
    } else if(folderId === '') {
        createFolder(prefix, folderName, function(data) {
            createFile(prefix, path, fileName, {'id':data}, function() { callback(); });
        });
    } else {
        createFile(prefix, path, fileName, folderId, function() { callback(); });
    }
    
}
function createFolder(prefix, folderName, callback) {
    
    let url = prefix + '/folders';
    
    axios.post(url, {
        'folderName' : folderName 
    }).then(function (response) {
        
        let location    = response.headers.location;
        let temp        = location.split('/');
        let folderId    = temp[temp.length - 1];
        
        callback(folderId);

    }).catch(function (error) {
        console.log(error.message);
    }); 
    
}
function createFile(prefix, path, fileName, folderId, callback) {
    
    let stats = fs.statSync(path + '/' + fileName);
    let url   = prefix + '/attachments';
       
    axios.post(url, {
        'description'   : fileName,
        'name'          : fileName,
        'resourceName'  : fileName,
        'folder'        : folderId,
        'size'          : stats.size
    }).then(function (response) {
        prepareUpload(response.data, function() {
            uploadFile(path, fileName, response.data, function(fileId) {
                setStatus(prefix, fileId, function() {
                    callback();
                });
            });          
        });
    }).catch(function (error) {
        console.log(error.message);
    }); 
    
}
function prepareUpload(fileData, callback) {
    
    axios({
        method  : 'options',
        url     :  fileData.url, 
        headers : {
            'Accept'            : '*/*',
            'Accept-Encoding'   : 'gzip, deflate, br',
            'Accept-Language'   : 'en-US,en;q=0.9,de;q=0.8,en-GB;q=0.7',
            'Access-Control-Request-Headers': 'content-type,x-amz-meta-filename',
            'Access-Control-Request-Method' : 'PUT',
            'Host'              : 'plm360-aws-useast.s3.amazonaws.com',
            'Origin'            : 'https://' + settings.tenant + '.autodeskplm360.net',
            'Sec-Fetch-Mode'    : 'cors',
            'Sec-Fetch-Site'    : 'cross-site'
        }
    }).then(function (response) {
        callback();
    }).catch(function (error) {
        console.log(error.message);
    }); 
    
}
function uploadFile(path, fileName, fileData, callback) {
    
    let authorization = axios.defaults.headers.common['Authorization'];
   // let headers = fileData.extraHeaders;
        
    // headers['Accept']           = '*/*';
    // headers['Accept-Encoding']  =  'gzip, deflate, br';
    // headers['Accept-Language']  =  'en-US,en;q=0.9,de;q=0.8,en-GB;q=0.7';
    // headers['Host']             =  'plm360-aws-useast.s3.amazonaws.com';
    // headers['Origin']           =  'https://' + settings.tenant + '.autodeskplm360.net';
    // headers['Sec-Fetch-Mode']   =  'cors';
    // headers['Sec-Fetch-Site']   =  'cross-site';

    delete axios.defaults.headers.common['Authorization'];

    axios.put(fileData.url, fs.readFileSync(path + '/' + fileName),{
        headers : fileData.extraHeaders
    }).then(function (response) {
        axios.defaults.headers.common['Authorization'] = authorization;
        callback(fileData.id);
    }).catch(function (error) {
        console.log(error);
        console.log(error.message);
    }); 
    
}
function setStatus(prefix, fileId, callback) {
    
    let url = prefix + '/attachments/' + fileId;

    axios.patch(url, {
        status : {
            'name' : 'CheckIn'
        }
    }).then(function (response) {
        callback();
    }).catch(function (error) {
        console.log(error.message);
    }); 
    
}
function createVersion(prefix, path, fileName, folderId, fileId, callback) {
    
    let stats   = fs.statSync(path + '/' + fileName);
    let url     = prefix + '/attachments/' + fileId;
    
    if(folderId === '') folderId = null;
    
    axios.post(url, {
        'description'   : fileName,
        'fileName'      : fileName,
        'name'          : fileName,
        'resourceName'  : fileName,
        'folder'        : folderId,
        'fileTypeString': 'file/type',
        'size'          : stats['size']
    }).then(function (response) {
        prepareUpload(response.data, function() {
            uploadFile(path, fileName, response.data, function(fileId) {
                setStatus(prefix, fileId, function() {
                    callback();
                });
            });
        });
    }).catch(function (error) {
        console.log(error.message);
    });    
    
}


// ITEM GRID
// ---------------------------------------------------------------------------------
exports.getGridColumns = function getGridColumns(wsId) {

    let url = 'https://' + settings.tenant + '.autodeskplm360.net/api/v3/workspaces/' + wsId + '/views/13/fields';
    
    return axios.get(url).then(function (response) {
        return response.data;
    }).catch(function (error) {
        console.log(error.message);
        return [];
    });

}
exports.getGridRows = function getGridRows(wsId, dmsId) {

    let url = 'https://' + settings.tenant + '.autodeskplm360.net/api/v3/workspaces/' + wsId + '/items/' + dmsId + '/views/13/rows';
    
    return axios.get(url).then(function (response) {
        return response.data;
    }).catch(function (error) {
        console.log(error.message);
        return [];
    });

}
exports.addGridRow = function addGridRow(params) {
    
    let url     = 'https://' + settings.tenant + '.autodeskplm360.net' + params.link + '/views/13/rows';    
    let rowData = [];
    let self    = params.link.split('/');
    let wsId    = self[4];

    for(field of params.row) {
        rowData.push({
            '__self__' : '/api/v3/workspaces/' + wsId + '/views/13/fields/' + field.fieldId,
            'urn'      : 'urn:adsk.plm:tenant.workspace.view.field:ADSKDICKMAS.' + wsId + '.13.ID',
            'value'    : field.value
        });
    }

    return axios.post(url, {
        'rowData' : rowData
    }).then(function() {
        return true;
    }).catch(function(error) {
        console.log(error);
        return false;
    });

};


// ITEM PROJECT
// ---------------------------------------------------------------------------------
exports.getProject = function getProject(wsId, dmsId) {

    let url = 'https://' + settings.tenant + '.autodeskplm360.net/api/v3/workspaces/' + wsId + '/items/' + dmsId + '/views/16';
    
    return axios.get(url).then(function (response) {
        return response.data;
    }).catch(function (error) {
        console.log(error.message);
        return [];
    });

}


// ITEM MANAGED ITEMS
// ---------------------------------------------------------------------------------
exports.getManagedItems = function getManagedItems(wsId, dmsId) {

    let url = 'https://' + settings.tenant + '.autodeskplm360.net/api/v3/workspaces/' + wsId + '/items/' + dmsId + '/views/11';
    
    return axios.get(url).then(function (response) {
        return response.data;
    }).catch(function (error) {
        console.log(error.message);
        return [];
    });

}
exports.getManagedItemsColumns = function getManagedItems(wsId) {

    let url = 'https://' + settings.tenant + '.autodeskplm360.net/api/v3/workspaces/' + wsId + '/views/11/fields';
    
    return axios.get(url).then(function (response) {
        return response.data;
    }).catch(function (error) {
        console.log(error.message);
        return [];
    });

}


// ITEM MILESTONES
// ---------------------------------------------------------------------------------
exports.getMilestones = function getMilestones(wsId, dmsId) {

    let url = 'https://' + settings.tenant + '.autodeskplm360.net/api/v3/workspaces/' + wsId + '/items/' + dmsId + '/views/17?asc=date';
    
    return axios.get(url).then(function (response) {
        return response.data;
    }).catch(function (error) {
        console.log(error.message);
        return [];
    });

}


// ITEM CHANGE LOG
// ---------------------------------------------------------------------------------
exports.getChangeLog = function getChangeLog(wsId, dmsId) {

    let url = 'https://' + settings.tenant + '.autodeskplm360.net/api/v3/workspaces/' + wsId + '/items/' + dmsId + '/logs?desc=timeStamp&limit=100&offset=0';
    
    return axios.get(url).then(function (response) {
        return response.data;
    }).catch(function (error) {
        console.log(error.message);
        return [];
    });

}


// Perform Workflow Transition
exports.performTransition = function performTransition(params) {

    let url   = 'https://' + settings.tenant + '.autodeskplm360.net/api/v3/workspaces/' + params.wsId + '/items/' + params.dmsId + '/workflows/1/transitions';
    
    return axios.post(url, {
        'comment' : (typeof params.comment === 'undefined') ? 'Transitioned by external program' : params.comment
    },{
        headers : {
            'content-location' : '/api/v3/workspaces/' + params.wsId + '/workflows/1/transitions/' + params.transitionId
        }
    }).then(function () {
       return true;
    }).catch(function (error) {
        if(error.statusCode === 303) {
            return true;
        } else {
            console.log(error);
            return false;
        }
    });

}


// TABLEAUS
// ---------------------------------------------------------------------------------
exports.getTableau = function getTableau(link) {

    let url = 'https://' + settings.tenant + '.autodeskplm360.net/' + link;
    
    return axios.get(url, {
        'headers' : {
            'Accept' : 'application/vnd.autodesk.plm.meta+json'
        }
    }).then(function (response) {
        return response.data;
    }).catch(function (error) {
        console.log(error.message);
        return [];
    });

}


// SECURITY
// ---------------------------------------------------------------------------------
exports.getGroups = function getGroups(params) {

    let url = 'https://' + settings.tenant + '.autodeskplm360.net/api/v3/groups';
    
    return axios.get(url, {
        headers : {
            Accept : 'application/vnd.autodesk.plm.groups.bulk+json'
        }
    }).then(function (response) {
        return response.data.items;
    }).catch(function (error) {
        console.log(error.message);
        return [];
    });

}
exports.getUsers = function getUsers(params) {

    let offset      = (typeof params.offset             === 'undefined') ?     0 : params.offset;
    let limit       = (typeof params.limit              === 'undefined') ?   100 : params.limit;
    let admin       = (typeof params.includeTenantAdmin === 'undefined') ?  true : params.includeTenantAdmin;
    let mappedOnly  = (typeof params.mappedOnly         === 'undefined') ? false : params.mappedOnly;
    let activeOnly  = (typeof params.activeOnly         === 'undefined') ? false : params.activeOnly;

    let url = 'https://' + settings.tenant + '.autodeskplm360.net/api/v3/users';
        url += '?limit=' + limit;
        url += '&offset=' + offset;
        url += '&includeAlertView=false'
        url += '&includeTenantAdmin=' + admin
        url += '&mappedOnly=' + mappedOnly
        url += '&activeOnly=' + activeOnly;
   

    return axios.get(url, {
        headers : {
            Accept : 'application/vnd.autodesk.plm.users.bulk+json'
        }
    }).then(function (response) {
        let result = (response.data === '') ? { 'items' : [] } : response.data;
        return result;
    }).catch(function (error) {
        console.log(error.message);
        return { 'items' : [] };
    });

}
exports.getUserDetails = function getUserDetails(link) {

    let url = 'https://' + settings.tenant + '.autodeskplm360.net' + link;

    return axios.get(url).then(function (response) {
        return(response.data);
    }).catch(function (error) {
        console.log(error);
    });

}
exports.addUser = function addUser(params) {

    let url = 'https://' + settings.tenant + '.autodeskplm360.net/api/v3/users';
    
    return axios.post(url, {
        'email'         : params.email,
        'thumbnailPref' : 'Yes',
        'uomPref'       : 'Metric',
        'timezone'      : 'Etc/GMT+1',
        'licenseType'   : {
            'licenseCode': params.licenseCode   // P: Participant, S: Professional
        }        
    }).then(function (response) {
        return response.headers.location;
    }).catch(function (error) {
        console.log(error.message);
        return 'error';
    });

}
exports.assignGroups = function assignGroups(link, urns) {

    let url = link + '/groups';
    
    return axios.post(url, urns).then(function () {
        return true;
    }).catch(function (error) {
        console.log(error.message);
        return false;
    });

}
exports.setUserStatus = function setUserStatus(params) {

    //  let params = {
    //      'userId' : '3wkrs',
    //      'status' : 'Deleted'     (Inactive, Deleted, Active)
    //  }

    let url = 'https://' + settings.tenant + '.autodeskplm360.net/api/v3/users/' + params.userId;
   
    return axios.patch(url,  [{
        'op'    : 'replace',
        'path'  : '/userStatus',
        'value' : params.status
    }], {
        'headers' : {
            'Accept': 'application/json',
            'Content-Type': 'application/json-patch+json'
        }
    }).then(function (response) {
        return response.status;
    }).catch(function (error) {
        console.log(error.message);
        return false;
    });

}